#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-L2Rrp4R7I0KGXGB6JV4IFD
key:                  http-streams-0.8.9.9-L2Rrp4R7I0KGXGB6JV4IFD
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  7e6344ad85573a6c1be7737813a48676
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-L2Rrp4R7I0KGXGB6JV4IFD
depends:
    HsOpenSSL-0.11.7.9-4Ju4RPv3MxY9OC4WlRb8ML
    aeson-2.2.1.0-2aoKFKPwHseOu8oBERSIn
    attoparsec-0.14.4-CAVADdTBKeoK3WivOosynQ
    attoparsec-aeson-2.2.0.0-Ed6Ob9jRRBK16Z2UI4jvON base-4.18.2.1
    base64-bytestring-1.2.1.0-9t8HAadP59K2JwXTIu8Svu
    blaze-builder-0.4.4.1-GTLHGvKyk8lH2PyHpW0m9c bytestring-0.11.5.3
    case-insensitive-1.2.1.0-cn2el9kShe8gw58Kc65j7 directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-4ZoRN88sU7JHM9dt4zPLwn
    io-streams-1.5.2.2-DsqTmbwCPp474Aem6onXd9 mtl-2.3.1
    network-3.1.4.0-HNp7Plz2T5iBA2k1xbdmYs
    network-uri-2.6.4.2-LbMcOyx90ZBKbCJyfJJvCd
    openssl-streams-1.2.3.0-JuoqFe9WClQLvHEZBI2vXE text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-1lWFLFb7qnGGdfGyTf5Bys

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

